==> haskell-tls-1.9.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls
version:              1.9.0
visibility:           public
id:                   tls-1.9.0-6J8obW2Ylik4yHgZXn4WWr
key:                  tls-1.9.0-6J8obW2Ylik4yHgZXn4WWr
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-tls/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  70432bf1b73ba7c02e3917efce7d2634
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal Network.TLS.QUIC

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Client Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Control
    Network.TLS.Handshake.Key Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Server
    Network.TLS.Handshake.Signature Network.TLS.Handshake.State
    Network.TLS.Handshake.State13 Network.TLS.Hooks Network.TLS.IO
    Network.TLS.Imports Network.TLS.KeySchedule Network.TLS.MAC
    Network.TLS.Measurement Network.TLS.Packet Network.TLS.Packet13
    Network.TLS.Parameters Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Disengage Network.TLS.Record.Engage
    Network.TLS.Record.Layer Network.TLS.Record.Reading
    Network.TLS.Record.Writing Network.TLS.Record.State
    Network.TLS.Record.Types Network.TLS.RNG Network.TLS.State
    Network.TLS.Session Network.TLS.Sending Network.TLS.Receiving
    Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls
hs-libraries:         HStls-1.9.0-6J8obW2Ylik4yHgZXn4WWr
depends:
    asn1-encoding-0.9.6-LGhJbxhD6Cf3nqUWbw5SbR
    asn1-types-0.3.4-t8imqzzH73RpySYDIbUs
    async-2.2.5-mpdT7StXVF2mjqEUwF4MR base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    crypton-1.0.0-IIrgJZNDZ7S1y2tDaxcuSw
    crypton-x509-1.7.6-KqX85qTySKeFxRn8MpKf51
    crypton-x509-store-1.6.9-3zX3CAeaxJ8KGHR5IlW4GG
    crypton-x509-validation-1.6.13-1RDHsk35VOtCXPNbA5QgM7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-29qUxJkoDip75hxElAm7gZ transformers-0.5.6.2
    unix-time-0.4.16-IMvxW4eqnpEHdzOghw6FW6

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-1.9.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls
version:              1.9.0
visibility:           public
id:                   tls-1.9.0-K5div0VFXfDIV0dN6PgtYZ
key:                  tls-1.9.0-K5div0VFXfDIV0dN6PgtYZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-tls/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  f2592776fdce5ca12f5d1b9f4ae53612
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal Network.TLS.QUIC

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Client Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Control
    Network.TLS.Handshake.Key Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Server
    Network.TLS.Handshake.Signature Network.TLS.Handshake.State
    Network.TLS.Handshake.State13 Network.TLS.Hooks Network.TLS.IO
    Network.TLS.Imports Network.TLS.KeySchedule Network.TLS.MAC
    Network.TLS.Measurement Network.TLS.Packet Network.TLS.Packet13
    Network.TLS.Parameters Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Disengage Network.TLS.Record.Engage
    Network.TLS.Record.Layer Network.TLS.Record.Reading
    Network.TLS.Record.Writing Network.TLS.Record.State
    Network.TLS.Record.Types Network.TLS.RNG Network.TLS.State
    Network.TLS.Session Network.TLS.Sending Network.TLS.Receiving
    Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-1.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls
hs-libraries:         HStls-1.9.0-K5div0VFXfDIV0dN6PgtYZ
depends:
    asn1-encoding-0.9.6-DNWVWoTxdSnGlftGs3XJtZ
    asn1-types-0.3.4-4xFnmOuTTrxKMTGGSXSLkA
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1
    bytestring-0.11.5.3 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    crypton-1.0.0-DPZJlEmcVd8Aodr5WBuA08
    crypton-x509-1.7.6-L695FvnGrPr9CPCq3lVuZs
    crypton-x509-store-1.6.9-1Sd4TN1ckN12L96Cy20q5v
    crypton-x509-validation-1.6.13-EZ3gWoyzq8g8AnZwlLVh1R
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu transformers-0.5.6.2
    unix-time-0.4.16-6XNkEunbRxSEoHJTfr64py

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
